EncodeParam

Trait EncodeParam 

pub trait EncodeParam<T> {
    // Required method
    fn encode(runtime: &ConjureRuntime, value: T) -> Result<Vec<String>, Error>;
}
A trait implemented by URL parameter encoders used by custom Conjure client trait implementations.

Required Methods

fn encode(runtime: &ConjureRuntime, value: T) -> Result<Vec<String>, Error>

Encodes the value into a sequence of parameters.

When used with a path parameter, each returned string will be a separate path component. When used with a query parameter, each returned string will be the value of a separate query entry.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, D, U> EncodeParam<T> for AsRefEncoder<D, U>
where T: AsRef<U>, for<'a> D: EncodeParam<&'a U>,

Source

impl<T, U> EncodeParam<T> for DisplaySeqEncoder
where T: IntoIterator<Item = U>, U: Display,

Source

impl<T, U> EncodeParam<T> for PlainSeqEncoder
where T: IntoIterator<Item = U>, U: Plain,

Source

impl<T> EncodeParam<T> for DisplayEncoder
where T: Display,

Source

impl<T> EncodeParam<T> for PlainEncoder
where T: Plain,