Encoding

Trait Encoding 

pub trait Encoding {
    // Required methods
    fn content_type(&self) -> HeaderValue;
    fn serializer<'a>(
        &self,
        w: &'a mut Vec<u8>,
    ) -> Box<dyn SerializerState<'a> + 'a>;
    fn deserializer<'a>(
        &self,
        buf: &'a [u8],
    ) -> Box<dyn DeserializerState<'a> + 'a>;
}
An encoding of HTTP bodies.

Required Methods

fn content_type(&self) -> HeaderValue

The encoding’s MIME type.

fn serializer<'a>( &self, w: &'a mut Vec<u8>, ) -> Box<dyn SerializerState<'a> + 'a>

Returns state which will serialize the response body into the provided buffer.

fn deserializer<'a>(&self, buf: &'a [u8]) -> Box<dyn DeserializerState<'a> + 'a>

Returns state which will deserialize the request body from the provided buffer.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Encoding for conjure_http::client::JsonEncoding

Source

impl Encoding for conjure_http::server::JsonEncoding

Source

impl Encoding for conjure_http::client::SmileEncoding

Source

impl Encoding for conjure_http::server::SmileEncoding