SafeParams

Struct SafeParams 

pub struct SafeParams(/* private fields */);
A data structure storing safe-loggable parameters of a request.

This can be included in the response extensions of a request to be included in request logs.

Implementations

Source

impl SafeParams

pub fn new() -> Self

Creates a new, empty SafeParams.

pub fn insert<T>(&mut self, name: &'static str, value: &T)
where T: Serialize,

Inserts a parameter.

Panics

Panics if the value fails to serialize into an Any.

pub fn iter(&self) -> Iter<'_>

Returns an iterator over the parameters.