Module conjure

Module conjure 

Implementations for Conjure-generated endpoints.

Structs

FromPlainSeqDecoder
A decoder which converts a sequence of values via its FromPlain implementation into a collection via a FromIterator implementation.

Enums

BinaryRequestDeserializer
A request deserializer for binary body types.
BinaryResponseSerializer
A response serializer for binary types.
CollectionResponseSerializer
A body serializer for collection types.
FromPlainDecoder
A decoder which converts a single value using its FromPlain implementation.
FromPlainOptionDecoder
A decoder which converts an optional value using its FromPlain implementation.
OptionalBinaryResponseSerializer
A response serializer for optional binary types.
OptionalRequestDeserializer
A request deserializer for optional body types.